@@ -34,6 +34,7 @@
 #include <xcb/xtest.h>
 
 #include <X11/Xlib-xcb.h>
+#include <X11/XKBlib.h>
 
 #include "awesome.h"
 #include "spawn.h"
@@ -374,6 +375,9 @@ main(int argc, char **argv)
     sigemptyset(&sa.sa_mask);
     sigaction(SIGSEGV, &sa, 0);
 
+    /* XLib sucks */
+    XkbIgnoreExtension(True);
+
     /* X stuff */
     globalconf.display = XOpenDisplay(NULL);
     if (globalconf.display == NULL)
